% Auto-generated chapter 56 for malik
% Hadiths in this chapter: 28

\hadithdefcmd{malik}{1811}{حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ لأَخِيهِ يَا كَافِرُ ‏.‏ فَقَدْ بَاءَ بِهَا أَحَدُهُمَا ‏"‏ ‏.‏\hadithno{1811}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Abdullah ibn Dinar from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "If a man says to his muslim brother, 'O kafir!' it is true about one of them}}
\hadithdefcmd{malik}{1812}{وَحَدَّثَنِي مَالِكٌ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَمِعْتَ الرَّجُلَ يَقُولُ هَلَكَ النَّاسُ ‏.‏ فَهُوَ أَهْلَكُهُمْ ‏"‏ ‏.‏\hadithno{1812}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Suhayl ibn Abu Salih from his father from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "When you hear a man say, 'The people are ruined,' he himself is the most ruined of them all}}
\hadithdefcmd{malik}{1813}{وَحَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقُلْ أَحَدُكُمْ يَا خَيْبَةَ الدَّهْرِ ‏.‏ فَإِنَّ اللَّهَ هُوَ الدَّهْرُ ‏"‏ ‏.‏\hadithno{1813}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Let none of you complain about time, for Allah is time}}
\hadithdefcmd{malik}{1814}{وَحَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ عِيسَى ابْنَ مَرْيَمَ، لَقِيَ خِنْزِيرًا بِالطَّرِيقِ فَقَالَ لَهُ انْفُذْ بِسَلاَمٍ ‏.‏ فَقِيلَ لَهُ تَقُولُ هَذَا لِخِنْزِيرٍ فَقَالَ عِيسَى إِنِّي أَخَافُ أَنْ أُعَوِّدَ لِسَانِي النُّطْقَ بِالسُّوءِ ‏.‏\hadithno{1814}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik related to me from Yahya ibn Said that Isa ibn Maryam encountered a pig on the road. He said to it, "Go in peace." Somebody asked, "Do you say this to a pig?" Isa said, "I fear lest I accustom my tongue to evil speech}}
\hadithdefcmd{malik}{1815}{حَدَّثَنِي مَالِكٌ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَلْقَمَةَ، عَنْ أَبِيهِ، عَنْ بِلاَلِ بْنِ الْحَارِثِ الْمُزَنِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الرَّجُلَ لَيَتَكَلَّمُ بِالْكَلِمَةِ مِنْ رِضْوَانِ اللَّهِ مَا كَانَ يَظُنُّ أَنْ تَبْلُغَ مَا بَلَغَتْ يَكْتُبُ اللَّهُ لَهُ بِهَا رِضْوَانَهُ إِلَى يَوْمِ يَلْقَاهُ وَإِنَّ الرَّجُلَ لَيَتَكَلَّمُ بِالْكَلَمِةِ مِنْ سَخَطِ اللَّهِ مَا كَانَ يَظُنُّ أَنْ تَبْلُغَ مَا بَلَغَتْ يَكْتُبُ اللَّهُ لَهُ بِهَا سَخَطَهُ إِلَى يَوْمِ يَلْقَاهُ ‏"‏ ‏.‏\hadithno{1815}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Muhammad ibn Amr ibn Alqama from his father from Bilal ibn al-Harith al-Muzani that the Messenger of Allah, may Allah bless him and grant him peace, said, "A man speaks what is pleasing to Allah and he does not suspect that it will have the result that it does, and Allah will write for him His good pleasure for it until the day when he meets Him. And a man speaks what excites the wrath of Allah and he does not suspect that it will have the result that it does, and Allah will write His wrath for him for it until the day when he meets Him}}
\hadithdefcmd{malik}{1816}{وَحَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ أَبِي صَالِحٍ السَّمَّانِ، أَنَّهُ أَخْبَرَهُ أَنَّ أَبَا هُرَيْرَةَ قَالَ إِنَّ الرَّجُلَ لَيَتَكَلَّمُ بِالْكَلِمَةِ مَا يُلْقِي لَهَا بَالاً يَهْوِي بِهَا فِي نَارِ جَهَنَّمَ وَإِنَّ الرَّجُلَ لَيَتَكَلَّمُ بِالْكَلَمَةِ مَا يُلْقِي لَهَا بَالاً يَرْفَعُهُ اللَّهُ بِهَا فِي الْجَنَّةِ ‏.‏\hadithno{1816}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Abdullah ibn Dinar that Abu Salih as- Samman informed him that Abu Hurayra said, "Truly a man utters words to which he attaches no importance, and by them he falls into the fire of Jahannam, and truly a man utters words to which he attaches no importance, and by them Allah raises him into the Garden}}
\hadithdefcmd{malik}{1817}{حَدَّثَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ قَدِمَ رَجُلاَنِ مِنَ الْمَشْرِقِ فَخَطَبَا فَعَجِبَ النَّاسُ لِبَيَانِهِمَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مِنَ الْبَيَانِ لَسِحْرًا ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ إِنَّ بَعْضَ الْبَيَانِ لَسِحْرٌ ‏"‏ ‏.‏\hadithno{1817}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Zayd ibn Aslam that Abdullah ibn Umar said, "Two men from the east stood up and spoke, and people were amazed at their eloquence. The Messenger of Allah, may Allah bless him and grant him peace, said, 'Some eloquence is sorcery,' or he said, 'Part of eloquence is sorcery}}
\hadithdefcmd{malik}{1818}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ عِيسَى ابْنَ مَرْيَمَ، كَانَ يَقُولُ لاَ تُكْثِرُوا الْكَلاَمَ بِغَيْرِ ذِكْرِ اللَّهِ فَتَقْسُوَ قُلُوبُكُمْ فَإِنَّ الْقَلْبَ الْقَاسِيَ بَعِيدٌ مِنَ اللَّهِ وَلَكِنْ لاَ تَعْلَمُونَ وَلاَ تَنْظُرُوا فِي ذُنُوبِ النَّاسِ كَأَنَّكُمْ أَرْبَابٌ وَانْظُرُوا فِي ذُنُوبِكُمْ كَأَنَّكُمْ عَبِيدٌ فَإِنَّمَا النَّاسُ مُبْتَلًى وَمُعَافًى فَارْحَمُوا أَهْلَ الْبَلاَءِ وَاحْمَدُوا اللَّهَ عَلَى الْعَافِيَةِ ‏.‏\hadithno{1818}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Malik related to me that he heard that Isa ibn Maryam used to say, "Do not speak much without the mention of Allah for you will harden your hearts. A hard heart is far from Allah, but you do not know. Do not look at the wrong actions of people as if you were lords. Look at your wrong actions as if you were slaves. Some people are afflicted by wrong action and some people are protected from it. Be merciful to the people of affliction and praise Allah for His protection}}
\hadithdefcmd{malik}{1819}{وَحَدَّثَنِي مَالِكُ، أَنَّهُ بَلَغَهُ أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم كَانَتْ تُرْسِلُ إِلَى بَعْضِ أَهْلِهَا بَعْدَ الْعَتَمَةِ فَتَقُولُ أَلاَ تُرِيحُونَ الْكُتَّابَ\hadithno{1819}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me that he heard that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, sent a message to one of her family after the evening prayer, saying, "Will you not allow the recording angel to rest?}}
\hadithdefcmd{malik}{1820}{حَدَّثَنِي مَالِكٌ، عَنِ الْوَلِيدِ بْنِ عَبْدِ اللَّهِ بْنِ صَيَّادٍ، أَنَّ الْمُطَّلِبَ بْنَ عَبْدِ اللَّهِ بْنِ حَنْطَبَ الْمَخْزُومِيَّ، أَخْبَرَهُ أَنَّ رَجُلاً سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم مَا الْغِيبَةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَنْ تَذْكُرَ مِنَ الْمَرْءِ مَا يَكْرَهُ أَنْ يَسْمَعَ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ وَإِنْ كَانَ حَقًّا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا قُلْتَ بَاطِلاً فَذَلِكَ الْبُهْتَانُ ‏"‏ ‏.‏\hadithno{1820}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Malik related to me from al-Walid ibn Abdullah ibn Sayyad that al-Muttalib ibn Abdullah ibn Hantab al-Makhzumi informed him that a man asked the Messenger of Allah, may Allah bless him and grant him peace, "What is backbiting?" The Messenger of Allah, may Allah bless him and grant him peace, said, "It is to mention about a man what he does not want to hear." He said, "Messenger of Allah! Even if it is true?" The Messenger of Allah, may Allah bless him and grant him peace, said, "If you utter something false, then it is slander}}
\hadithdefcmd{malik}{1821}{حَدَّثَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ وَقَاهُ اللَّهُ شَرَّ اثْنَيْنِ وَلَجَ الْجَنَّةَ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ لاَ تُخْبِرْنَا ‏.‏ فَسَكَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ عَادَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ مِثْلَ مَقَالَتِهِ الأُولَى فَقَالَ لَهُ الرَّجُلُ لاَ تُخْبِرْنَا يَا رَسُولَ اللَّهِ ‏.‏ فَسَكَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِثْلَ ذَلِكَ أَيْضًا فَقَالَ الرَّجُلُ لاَ تُخْبِرْنَا يَا رَسُولَ اللَّهِ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِثْلَ ذَلِكَ أَيْضًا ‏.‏ ثُمَّ ذَهَبَ الرَّجُلُ يَقُولُ مِثْلَ مَقَالَتِهِ الأُولَى فَأَسْكَتَهُ رَجُلٌ إِلَى جَنْبِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ وَقَاهُ اللَّهُ شَرَّ اثْنَيْنِ وَلَجَ الْجَنَّةَ مَا بَيْنَ لَحْيَيْهِ وَمَا بَيْنَ رِجْلَيْهِ مَا بَيْنَ لَحْيَيْهِ وَمَا بَيْنَ رِجْلَيْهِ مَا بَيْنَ لَحْيَيْهِ وَمَا بَيْنَ رِجْلَيْهِ ‏"‏ ‏.‏\hadithno{1821}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Malik related to me from Zayd ibn Aslam from Ata ibn Yasar that the Messenger of Allah, may Allah bless him and grant him peace, said, "Whomever Allah protects from the evil of two things will enter the Garden." A man said, "Messenger of Allah, do not tell us!" The Messenger of Allah, may Allah bless him and grant him peace, was silent. Then the Messenger of Allah, may Allah bless him and grant him peace, repeated what he had said the first time. The man said to him, "Do not tell us, Messenger of Allah!" The Messenger of Allah, may Allah bless him and grant him peace, was silent. Then the Messenger of Allah, may Allah bless him and grant him peace, said the same thing again. The man said, "Do not tell us, Messenger of Allah!" Then the Messenger of Allah, may Allah bless him and grant him peace, said the same thing again. Then the man began to say what he had said previously and a man at his side silenced him. The Messenger of Allah, may Allah bless him and grant him peace, said, "Whomever Allah protects from the evil of two things will enter the Garden. They are what is between his jaws and what is between his legs, what is between his jaws and what is between his legs, what is between his jaws and what is between his legs}}
\hadithdefcmd{malik}{1822}{وَحَدَّثَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، دَخَلَ عَلَى أَبِي بَكْرٍ الصِّدِّيقِ وَهُوَ يَجْبِذُ لِسَانَهُ فَقَالَ لَهُ عُمَرُ مَهْ غَفَرَ اللَّهُ لَكَ ‏.‏ فَقَالَ أَبُو بَكْرٍ إِنَّ هَذَا أَوْرَدَنِي الْمَوَارِدَ ‏.‏\hadithno{1822}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Zayd ibn Aslam from his father that Umar ibn al-Khattab came upon Abu Bakr as-Siddiq pulling his tongue. Umar said to him, "Stop, may Allah forgive you!" Abu Bakr replied, "This has brought me to dangerous places}}
\hadithdefcmd{malik}{1823}{وَحَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، قَالَ كُنْتُ أَنَا وَعَبْدُ اللَّهِ بْنُ عُمَرَ، عِنْدَ دَارِ خَالِدِ بْنِ عُقْبَةَ الَّتِي بِالسُّوقِ فَجَاءَ رَجُلٌ يُرِيدُ أَنْ يُنَاجِيَهُ وَلَيْسَ مَعَ عَبْدِ اللَّهِ بْنِ عُمَرَ أَحَدٌ غَيْرِي وَغَيْرُ الرَّجُلِ الَّذِي يُرِيدُ أَنْ يُنَاجِيَهُ فَدَعَا عَبْدُ اللَّهِ بْنُ عُمَرَ رَجُلاً آخَرَ حَتَّى كُنَّا أَرْبَعَةً فَقَالَ لِي وَلِلرَّجُلِ الَّذِي دَعَاهُ اسْتَأْخِرَا شَيْئًا فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَتَنَاجَى اثْنَانِ دُونَ وَاحِدٍ ‏"‏ ‏.‏\hadithno{1823}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Abdullah ibn Dinar saying, "Abdullah ibn Umar and I were at the house of Khalid ibn Uqba who was away at the market. A man came who wanted to speak to Abdullah ibn Umar and I was the only other person present Abdullah ibn Umar called another man so that we were four and said to me and the man whom he had called, 'Go a little way off together, because I heard the Messenger of Allah, may Allah bless him and grant him peace, say, "Two do not converse secretly to the exclusion of another}}
\hadithdefcmd{malik}{1824}{وَحَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَانَ ثَلاَثَةٌ فَلاَ يَتَنَاجَى اثْنَانِ دُونَ وَاحِدٍ ‏"‏ ‏.‏\hadithno{1824}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "Two must not converse secretly to the exclusion of another person}}
\hadithdefcmd{malik}{1825}{حَدَّثَنِي مَالِكٌ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، أَنَّ رَجُلاً، قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَكْذِبُ امْرَأَتِي يَا رَسُولَ اللَّهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ خَيْرَ فِي الْكَذِبِ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ يَا رَسُولَ اللَّهِ أَعِدُهَا وَأَقُولُ لَهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ جُنَاحَ عَلَيْكَ ‏"‏ ‏.‏\hadithno{1825}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Malik related to me from Safwan ibn Sulaym that a man asked the Messenger of Allah, may Allah bless him and grant him peace, "Can I lie to my wife, Messenger of Allah?" The Messenger of Allah, may Allah bless him and grant him peace, said, "There is no good in lying." The man said, "Messenger of Allah! Shall I make her a promise and tell her?" The Messenger of Allah, may Allah bless him and grant him peace, said, "It will not be held against you}}
\hadithdefcmd{malik}{1826}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ، كَانَ يَقُولُ عَلَيْكُمْ بِالصِّدْقِ فَإِنَّ الصِّدْقَ يَهْدِي إِلَى الْبِرِّ وَالْبِرَّ يَهْدِي إِلَى الْجَنَّةِ وَإِيَّاكُمْ وَالْكَذِبَ فَإِنَّ الْكَذِبَ يَهْدِي إِلَى الْفُجُورِ وَالْفُجُورَ يَهْدِي إِلَى النَّارِ أَلاَ تَرَى أَنَّهُ يُقَالُ صَدَقَ وَبَرَّ وَكَذَبَ وَفَجَرَ ‏.‏\hadithno{1826}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me that he heard that Abdullah ibn Masud used to say, "You must tell the truth. Truthfulness leads to right action. Right action leads to the Garden. Beware of lying. Lying leads to corruption, and corruption leads to the Fire. Don't you see that it is said, 'He speaks the truth and acts rightly,' and, 'He lies and is corrupt}}
\hadithdefcmd{malik}{1827}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّهُ قِيلَ لِلُقْمَانَ مَا بَلَغَ بِكَ مَا نَرَى يُرِيدُونَ الْفَضْلَ ‏.‏ فَقَالَ لُقْمَانُ صِدْقُ الْحَدِيثِ وَأَدَاءُ الأَمَانَةِ وَتَرْكُ مَا لاَ يَعْنِينِي ‏.‏\hadithno{1827}\hadithgrade{Salim al-Hilali: Maqtu Sahih Lighairihi}\hadithtrans{Malik related to me that he heard that someone said to Luqman, "What has brought you to what we see?" meaning his high rank. Luqman said, "Truthful speech, fulfilling the trust, and leaving what does not concern me}}
\hadithdefcmd{malik}{1828}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ، كَانَ يَقُولُ لاَ يَزَالُ الْعَبْدُ يَكْذِبُ وَتُنْكَتُ فِي قَلْبِهِ نُكْتَةٌ سَوْدَاءُ حَتَّى يَسْوَدَّ قَلْبُهُ كُلُّهُ فَيُكْتَبَ عِنْدَ اللَّهِ مِنَ الْكَاذِبِينَ ‏.‏\hadithno{1828}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me that he heard that Abdullah ibn Masud used to say, "The slave continues to lie and a black spot grows in his heart until all his heart becomes black. Then he is written, in Allah's sight, among the liars}}
\hadithdefcmd{malik}{1829}{وَحَدَّثَنِي مَالِكٌ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، أَنَّهُ قَالَ قِيلَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَيَكُونُ الْمُؤْمِنُ جَبَانًا فَقَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ فَقِيلَ لَهُ أَيَكُونُ الْمُؤْمِنُ بَخِيلاً فَقَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ فَقِيلَ لَهُ أَيَكُونُ الْمُؤْمِنُ كَذَّابًا فَقَالَ ‏"‏ لاَ ‏"‏ ‏.‏\hadithno{1829}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Malik related to me that Safwan ibn Sulaym said, "The Messenger of Allah, may Allah bless him and grant him peace, was asked, 'Can the mumin be a coward?' He said, 'Yes.' He was asked, 'Can the mumin be a miser?' He said, 'Yes.' He was asked, 'Can the mumin be a liar?' He said, 'No}}
\hadithdefcmd{malik}{1830}{حَدَّثَنِي مَالِكٌ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ يَرْضَى لَكُمْ ثَلاَثًا وَيَسْخَطُ لَكُمْ ثَلاَثًا يَرْضَى لَكُمْ أَنْ تَعْبُدُوهُ وَلاَ تُشْرِكُوا بِهِ شَيْئًا وَأَنْ تَعْتَصِمُوا بِحَبْلِ اللَّهِ جَمِيعًا وَأَنْ تَنَاصَحُوا مَنْ وَلاَّهُ اللَّهُ أَمْرَكُمْ وَيَسْخَطُ لَكُمْ قِيلَ وَقَالَ وَإِضَاعَةَ الْمَالِ وَكَثْرَةَ السُّؤَالِ ‏"‏ ‏.‏\hadithno{1830}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Suhayl ibn Abi Salih from his father from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Allah is pleased with three things from you, and He is angry with three things from you. He is pleased that you worship Him and do not associate anything with Him, and that you take hold of the rope of Allah altogether, and that you give good counsel to the one to whom Allah gives command over you. He is angry with you for gossip, squandering property, and asking too many questions}}
\hadithdefcmd{malik}{1831}{وَحَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مِنْ شَرِّ النَّاسِ ذُو الْوَجْهَيْنِ الَّذِي يَأْتِي هَؤُلاَءِ بِوَجْهٍ وَهَؤُلاَءِ بِوَجْهٍ ‏"‏ ‏.‏\hadithno{1831}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "One of the most evil of people is the two-faced person who shows one face to these people and another face to those people}}
\hadithdefcmd{malik}{1832}{حَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ أُمَّ سَلَمَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ يَا رَسُولَ اللَّهِ أَنَهْلِكُ وَفِينَا الصَّالِحُونَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَعَمْ إِذَا كَثُرَ الْخَبَثُ ‏"‏ ‏.‏\hadithno{1832}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Malik related to me that he had heard that Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, said, "Messenger of Allah! Shall we be destroyed while there are people who are salih among us?" The Messenger of Allah, may Allah bless him and grant him peace, said, "Yes, if there is much wickedness}}
\hadithdefcmd{malik}{1833}{وَحَدَّثَنِي مَالِكٌ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي حَكِيمٍ، أَنَّهُ سَمِعَ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، يَقُولُ كَانَ يُقَالُ إِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى لاَ يُعَذِّبُ الْعَامَّةَ بِذَنْبِ الْخَاصَّةِ وَلَكِنْ إِذَا عُمِلَ الْمُنْكَرُ جِهَارًا اسْتَحَقُّوا الْعُقُوبَةَ كُلُّهُمْ ‏.‏\hadithno{1833}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik related to me that Ismail ibn Abi Hakim heard Umar ibn Abd al-Aziz say, "Some say that Allah the Blessed, the Exalted, will not punish the many for the wrong action of the few. However, when the objectionable action is committed openly, then they all deserve to be punished}}
\hadithdefcmd{malik}{1834}{حَدَّثَنِي مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، وَخَرَجْتُ، مَعَهُ حَتَّى دَخَلَ حَائِطًا فَسَمِعْتُهُ وَهُوَ، يَقُولُ وَبَيْنِي وَبَيْنَهُ جِدَارٌ - وَهُوَ فِي جَوْفِ الْحَائِطِ - عُمَرُ بْنُ الْخَطَّابِ أَمِيرُ الْمُؤْمِنِينَ بَخٍ بَخٍ وَاللَّهِ لَتَتَّقِيَنَّ اللَّهَ أَوْ لَيُعَذِّبَنَّكَ ‏.‏\hadithno{1834}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Ishaq ibn Abdullah ibn Abi Talha that Anas ibn Malik said, "I heard Umar ibn al-Khattab, when I was going out with him to visit an orchard, say to himself, and there was a wall between him and me and he was inside the garden, 'Umar ibn al-Khattab, amir al-muminin! Well done! Well done! By Allah, fear Allah or he will punish you}}
\hadithdefcmd{malik}{1835}{قَالَ مَالِكٌ وَبَلَغَنِي أَنَّ الْقَاسِمَ بْنَ مُحَمَّدٍ كَانَ يَقُولُ أَدْرَكْتُ النَّاسَ وَمَا يَعْجَبُونَ بِالْقَوْلِ ‏.‏ قَالَ مَالِكٌ يُرِيدُ بِذَلِكَ الْعَمَلَ إِنَّمَا يُنْظَرُ إِلَى عَمَلِهِ وَلاَ يُنْظَرُ إِلَى قَوْلِهِ ‏.‏\hadithno{1835}\hadithgrade{Salim al-Hilali: Maqtu Hasan}\hadithtrans{Malik said, "I heard that al-Qasim ibn Muhammad used to say, 'I have seen the people, (i.e. the companions), and they were not impressed by speech.' " Malik said, "He meant that only action and deeds would be looked at, not words}}
\hadithdefcmd{malik}{1836}{حَدَّثَنِي مَالِكٌ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، أَنَّهُ كَانَ إِذَا سَمِعَ الرَّعْدَ، تَرَكَ الْحَدِيثَ\hadithno{1836}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me that Amir ibn Abdullah ibn az-Zubayr would stop speaking when he heard thunder and say, "Glory be to Allah whom the thunder glorifies with His praise and the angels from the fear of Him." (Subhana-aladhee yusabihu ar-radu bi hamdihi wa mala'ikatu min khiyfatihi.) Then he would say, "This is a severe warning to the people of the earth}}
\hadithdefcmd{malik}{1837}{حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّ أَزْوَاجَ النَّبِيِّ، صلى الله عليه وسلم حِينَ تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَرَدْنَ أَنْ يَبْعَثْنَ عُثْمَانَ بْنَ عَفَّانَ إِلَى أَبِي بَكْرٍ الصِّدِّيقِ فَيَسْأَلْنَهُ مِيرَاثَهُنَّ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ لَهُنَّ عَائِشَةُ أَلَيْسَ قَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ نُورَثُ مَا تَرَكْنَا فَهُوَ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{1837}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Ibn Shihab from Urwa ibn az-Zubayr from A'isha, umm al-muminin that when the Messenger of Allah, may Allah bless him and grant him peace, died, the wives of the Prophet, may Allah bless him and grant him peace, wanted to send Uthman ibn Affan to Abu Bakr as-Siddiq to ask him about their inheritance from the Messenger of Allah, may Allah bless him and grant him peace A'isha said to them, "Didn't the Messenger of Allah, may Allah bless him and grant him peace, say, 'No one inherits from us. What we leave is sadaqa}}
\hadithdefcmd{malik}{1838}{وَحَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقْتَسِمُ وَرَثَتِي دَنَانِيرَ مَا تَرَكْتُ بَعْدَ نَفَقَةِ نِسَائِي وَمُؤْنَةِ عَامِلِي فَهُوَ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{1838}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "My inheritance is not divided up by the dinar. What I leave apart from the maintenance of my wives and provision for my servant is sadaqa}}
